@@ -85,17 +85,17 @@ class PowerSpectrumTransform( object ) :
 
             Arguments :
 
-                x - Incident signal ( array( complex | float ), list( complex | float ) ).
+                x : typing.Union[ numpy.ndarray, list ] - incident signal.
 
-                b - Forward coefficient ( array( float ), list( float ) ).
+                b : typing.Union[ numpy.ndarray, list ] - forward coefficient.
 
-                index - Index ( int ).
+                index : int.
 
             Returns :
 
-                y - Reference signal ( array( float ) ).
+                y : numpy.ndarray - reference signal.
 
-                f - Normalized frequency relative to Nyquist in [ -1.0, 1.0 ) ( array( float ) ).
+                f : numpy.ndarray - relative to Nyquist in [ -1.0, 1.0 ).
         """
 
         if ( ( not numpy.isscalar( x ) ) and ( not isinstance( x, numpy.ndarray ) ) ) :
